@@ -1,4 +1,5 @@
 from .checker import SchemaChecker
+from .formats import FormatOptions
 from .loaders import instance_loader_from_args, schema_loader_from_args
 from .parse_cli import parse_args
 
@@ -10,10 +11,13 @@ def main(cli_args=None):
 
     instance_loader = instance_loader_from_args(args)
 
+    format_opts = FormatOptions(
+        enabled=not args.disable_format, regex_behavior=args.format_regex
+    )
     checker = SchemaChecker(
         schema_loader,
         instance_loader,
-        format_enabled=not args.disable_format,
+        format_opts=format_opts,
         traceback_mode=args.traceback_mode,
     )
     checker.run()
